# SKPD: A General Framework of Signal Region Detection in Image Regression

## Citations

Wu, S. and Feng, L. (2021)  SKPD: A General Framework of Signal Region Detection in Image Regression".

Author email: sanyouwsy@gmail.com

## Environment and usage

The following environments are required:

- Python 3.7 (anaconda is preferable)
- k3d (for visualize tensor case, not necessarily required)

The usage refer to the **Examples.ipynb**


<!-- ##  Matrix example shows

An illustration of estimated coefficients $ \hat{C} \in\mathbb{R}^{128\times 128}$ in the linear model simulation with $n=1000$ and noise level $\sigma = 1$. From left to right columns: True signals; our 1-term SKPD; 3-term SKPD.

![matrix_examples](https://github.com/SanyouWu/SKPD/blob/main/matrix_examples.png)

## Tensor example shows

![matrix_examples](https://github.com/SanyouWu/SKPD/blob/main/tensor_example.png) -->

